summaryrefslogtreecommitdiffstats
path: root/test/set_extent.c
diff options
context:
space:
mode:
Diffstat (limited to 'test/set_extent.c')
-rw-r--r--test/set_extent.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/test/set_extent.c b/test/set_extent.c
index 911a9a0..4bb324f 100644
--- a/test/set_extent.c
+++ b/test/set_extent.c
@@ -653,11 +653,11 @@ int main( void )
/*-------------------------------------------------------------------------
* test a dataset with initialized chunks
*-------------------------------------------------------------------------
*/
- TESTING("initialized chunks");
+ TESTING("non initialized chunks");
dims3[ 0 ] = 90;
dims3[ 1 ] = 90;
@@ -653,11 +653,11 @@ int main( void )
/*-------------------------------------------------------------------------
- * test a dataset with initialized chunks
+ * test a dataset with non initialized chunks
*-------------------------------------------------------------------------
*/